=encoding utf8

=head1 NAME

Locale::CLDR::Locales::Az::Cyrl::Az - Package for language Azerbaijani

=cut

package Locale::CLDR::Locales::Az::Cyrl::Az;
# This file auto generated from Data\common\main\az_Cyrl_AZ.xml
#	on Sat  6 Jan 12:50:56 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.40.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Az::Cyrl');
no Moo;

1;

# vim: tabstop=4
